Documentation
¶
Overview ¶
Package signcrypt implements an integrated signcryption scheme using Ristretto255 and Newplex.
Index ¶
Constants ¶
const Overhead = 32 + 32 + 32
Overhead is the length, in bytes, of the additional data added to a plaintext to produce a signcrypted ciphertext.
Variables ¶
This section is empty.
Functions ¶
func Open ¶
func Open(domain string, dR *ristretto255.Scalar, qS *ristretto255.Element, ciphertext []byte) ([]byte, error)
Open decrypts and verifies a ciphertext produced by Seal. Returns either the confidential, authentic plaintext or newplex.ErrInvalidCiphertext.
func Seal ¶
func Seal(domain string, dS *ristretto255.Scalar, qR *ristretto255.Element, rand, message []byte) []byte
Seal encrypts and signs the message to protect its confidentiality and authenticity. Only the owner of the receiver's private key can decrypt it, and only the owner of the sender's private key could have sent it.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.